This is the mail archive of the glibc-cvs@sourceware.org mailing list for the glibc project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

GNU C Library master sources branch master updated. glibc-2.26-330-g3bdfd9f


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU C Library master sources".

The branch, master has been updated
       via  3bdfd9fbed7165e75624845a3dab13f42b899096 (commit)
      from  65b22ebc615e6cbb3e8e9102762c362a9d9ecffd (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://sourceware.org/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=3bdfd9fbed7165e75624845a3dab13f42b899096

commit 3bdfd9fbed7165e75624845a3dab13f42b899096
Author: Samuel Thibault <samuel.thibault@ens-lyon.org>
Date:   Sun Sep 10 21:09:28 2017 +0200

    sunrpc/tst-udp-nonblocking: Fix timeout value
    
    This a follow-up to 00c3da4 ('sunrpc/tst-udp-timeout: Fix timeout value')
    
    * sunrpc/tst-udp-nonblocking.c (do_test): Increase timeout to 0.75
    seconds.

diff --git a/ChangeLog b/ChangeLog
index 7a2f865..555c3df 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -2,6 +2,8 @@
 
 	* sunrpc/tst-udp-timeout.c (test_udp_server): Increase timeout to 2.5
 	seconds.
+	* sunrpc/tst-udp-nonblocking.c (do_test): Increase timeout to 0.75
+	seconds.
 	* elf/rtld-Rules: Fix $(error) use.
 
 2017-09-09  Mike FABIAN  <mfabian@redhat.com>
diff --git a/sunrpc/tst-udp-nonblocking.c b/sunrpc/tst-udp-nonblocking.c
index c6a6849..46237a2 100644
--- a/sunrpc/tst-udp-nonblocking.c
+++ b/sunrpc/tst-udp-nonblocking.c
@@ -257,9 +257,9 @@ do_test (void)
         /* Shorter timeout to prefer this server.  These timeouts must
            be much shorter than the 5-second per-response timeout
            configured with clntudp_create.  */
-        query.timeout_ms = 700;
+        query.timeout_ms = 750;
       else
-        query.timeout_ms = 1400;
+        query.timeout_ms = 1500;
       struct test_response response = { 0 };
       /* NB: Do not check the return value.  The server reply will
          prove that the call worked.  */
@@ -289,8 +289,8 @@ do_test (void)
   if (test_verbose)
     printf ("info: send/receive took %f seconds\n",
             after_pings - before_pings);
-  /* Expected timeout is 0.7 seconds.  */
-  TEST_VERIFY (0.7 <= after_pings - before_pings);
+  /* Expected timeout is 0.75 seconds.  */
+  TEST_VERIFY (0.75 <= after_pings - before_pings);
   TEST_VERIFY (after_pings - before_pings < 1.2);
 
   uint32_t xid;

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog                    |    2 ++
 sunrpc/tst-udp-nonblocking.c |    8 ++++----
 2 files changed, 6 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
GNU C Library master sources


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]